@@ -40,17 +40,17 @@
 import lxml.html
 import re
 import sys
-from datetime import datetime
 
 def platform():
   """returns string of platform, as displayed for buildbot builds"""
   # XXX this should use the same code as buildbot
+
   if sys.platform == 'linux2':
     return 'linux'
   elif sys.platform == 'win32':
     return 'win32'
   elif sys.platform == 'darwin':
-    return 'macosx64'
+    return 'macosx'
   raise NotImplementedError
 
 class GetLatestTinderbox(object):
@@ -79,30 +79,22 @@ class GetLatestTinderbox(object):
   def platform_regex(self):
     """return the platform part of the regex"""
     regex = {'linux': 'linux-i686',
-             'linux64': 'linux-x86_64',
              'win32': 'win32',
-             'win64': 'win64-x86_64',
-             'macosx': 'mac',
-             'macosx64': 'mac64',
-             }
+             'macosx': 'mac'}
     return regex[self.platform]
 
   def build_regex(self):
     """the full regex for a build"""
     regex = {'linux': r'\.tar\.bz',
-             'linux64': r'\.tar\.bz',
              'win32': r'\.zip',
-             'win64': r'\.zip',
-             'macosx': r'\.dmg',
-             'macosx64': r'\.dmg',
-             }
+             'macosx': r'\.dmg'}
     return self.regex + regex[self.platform]
 
   def tests_regex(self):
     return self.regex + r'\.tests\.zip'
 
   def symbols_regex(self):
-    return self.regex + r'\.crashreporter-symbols.*\.zip'
+    return self.regex + r'\.crashreporter-symbols\.zip'
 
   def log_regex(self):
     """regular expression for all logs"""
@@ -130,10 +122,7 @@ class GetLatestTinderbox(object):
   def latest_url(self, regex, url=None):
     if isinstance(regex, basestring):
       regex = re.compile(regex)
-    if url is None:
-      _builds = self.builds(url)
-    else:
-      _builds = {url: url}
+    _builds = self.builds(url)
     for latest in sorted(_builds.keys(), reverse=True):
       build_info = _builds[latest]
       element = lxml.html.parse(build_info)
@@ -196,12 +185,6 @@ def main(args=sys.argv[1:]):
                     help='list test logs')
   parser.add_option('--log', '-l', dest='log',
                     help='print the URL of a specific log file')
-  parser.add_option('--url', '-u', dest='url',
-                    help="get builds from a specific url")
-  parser.add_option('--builds', dest='builds', action='store_true', default=False,
-                    help="list builds found")
-  parser.add_option('--datestamp', dest='datestamp',
-                    help='date stamp format')
   options, args = parser.parse_args(args)
 
   # check parsed options
@@ -210,43 +193,28 @@ def main(args=sys.argv[1:]):
   if options.symbols and options.tests:
     parser.error("Can't specify --tests and --symbols")
 
-  # instantiate class
   latest_tinderbox = GetLatestTinderbox(options.product, options.platform, options.debug)
 
-  # print out all builds currently in the tinderbox URL
-  if options.builds:
-    builds = latest_tinderbox.builds(options.url)
-    for key in sorted(builds.keys()):
-      build = builds[key]
-      if options.datestamp:
-        key = datetime.fromtimestamp(key).strftime(options.datestamp)
-      print '%s : %s' % (key, build)
-    return
-
-  # print out all logs found
   if options.logs:
-    logs = latest_tinderbox.logs(options.url)
+    logs = latest_tinderbox.logs()
     for key in sorted(logs.keys()):
       print '%s: %s' % (key, logs[key])
     return
 
-  # print out the URL for a specific log
   if options.log:
-    logs = latest_tinderbox.logs(options.url)
+    logs = latest_tinderbox.logs()
     return logs[options.log]
 
   if options.tests:
-    latest = latest_tinderbox.latest_tests_url(options.url)
+    latest = latest_tinderbox.latest_tests_url()
   elif options.symbols:
-    latest = latest_tinderbox.latest_symbols_url(options.url)
+    latest = latest_tinderbox.latest_symbols_url()
   else:
-    latest = latest_tinderbox.latest_build_url(options.url)
+    latest = latest_tinderbox.latest_build_url()
   return latest
 
 def setuptools_main(args=sys.argv[1:]):
-  retval = main(args)
-  if retval is not None:
-    print retval
+  print main(args)
 
 if __name__ == '__main__':
   print main()
